

<!doctype html>

{% load static %}
<html lang="en">
<head>
  <meta charset="utf-8">

  <title>Django Live Dashboard</title>
  <meta name="description" content="Live runtime dashboard for Django">
  <link rel="stylesheet" href="{% static "django_live_dashboard/index.css" %}" />
  <script>
    window.WS_PATH = "{% url "django_live_dashboard_index" %}";
    window.ROOT_PATH = "{% url "django_live_dashboard_index" %}"
  </script>
</head>

<body>
  <app></app>
  <script src="{% static "django_live_dashboard/index.js" %}"></script>
  <script src="{% static "django_live_dashboard/vendor.js" %}"></script>
</body>
</html>
